import _extends from "@babel/runtime/helpers/extends";

/* eslint-disable max-len */
import React from "react";
import PropTypes from "prop-types";
import classnames from "classnames";
import makeStyles from "../styles/makeStyles";
import { getShades } from "../styles/colors";

var deprecationWarning = function deprecationWarning(message) {
  if (process.env.NODE_ENV === "development") {
    // eslint-disable-next-line no-console
    console.warn("[Clever-react]: ".concat(message));
  }
};

var getClasses = makeStyles(function (_ref) {
  var colors = _ref.cleverUI.colors;
  return {
    root: function root(_ref2) {
      var rotation = _ref2.rotation,
          padding = _ref2.padding,
          size = _ref2.size,
          color = _ref2.color,
          shade = _ref2.shade;
      var res = {
        color: colors[color] ? colors[color][shade] : color
      };

      if (rotation > 0) {
        res.transform = "rotate(".concat(rotation, "deg)");
      }

      if (padding > 0) {
        res.padding = "".concat(size * padding / 200, "px");
      }

      return res;
    }
  };
});
var shadesList = getShades();

function Puzzle(props) {
  var classes = getClasses(props);
  var size = props.size,
      padding = props.padding,
      className = props.className,
      onMouseEnter = props.onMouseEnter,
      onMouseLeave = props.onMouseLeave;
  var sizeIcon = size;
  var otherProps = {
    className: classnames(className, classes.root),
    onMouseEnter: onMouseEnter,
    onMouseLeave: onMouseLeave
  };

  if (padding) {
    deprecationWarning("The padding prop is deprecated, use a className for customization");
    sizeIcon = sizeIcon * (100 - padding) / 100;
  }

  return /*#__PURE__*/React.createElement("svg", _extends({
    viewBox: "0 0 16 16",
    fill: "none",
    height: sizeIcon,
    width: sizeIcon
  }, otherProps), /*#__PURE__*/React.createElement("path", {
    d: "M11.333 14.667A1.333 1.333 0 0 1 10 13.333v-.666a.667.667 0 1 0-1.333 0v.666c0 .737-.597 1.334-1.334 1.334h-2A1.333 1.333 0 0 1 4 13.333v-2h-.667a2 2 0 0 1 0-4H4v-2C4 4.593 4.6 4 5.333 4h2v-.667a2 2 0 1 1 4 0V4h2c.737 0 1.334.597 1.334 1.333v2c0 .737-.597 1.334-1.334 1.334h-.666a.667.667 0 0 0 0 1.333h.666c.737 0 1.334.597 1.334 1.333v2c0 .737-.597 1.334-1.334 1.334h-2Zm2-1.334v-2h-.666a2 2 0 0 1 0-4h.666v-2h-2A1.333 1.333 0 0 1 10 4v-.667a.667.667 0 0 0-1.333 0V4c0 .736-.597 1.333-1.334 1.333h-2v2c0 .737-.597 1.334-1.333 1.334h-.667a.667.667 0 0 0 0 1.333H4c.736 0 1.333.597 1.333 1.333v2h2v-.666a2 2 0 1 1 4 0v.666h2Z",
    fill: "currentColor"
  }));
}

Puzzle.propTypes = {
  color: PropTypes.string,
  className: PropTypes.string,
  size: PropTypes.number,
  onMouseEnter: PropTypes.func,
  onMouseLeave: PropTypes.func,
  rotation: PropTypes.number,
  shade: PropTypes.oneOf(shadesList),
  padding: PropTypes.number
};
Puzzle.defaultProps = {
  color: "neutral",
  size: 24,
  className: "",
  rotation: 0,
  shade: 500,
  padding: 0,
  onMouseEnter: function onMouseEnter() {},
  onMouseLeave: function onMouseLeave() {}
};
export default Puzzle;