import "@emotion/react";
import { CSSObject } from "@emotion/serialize";
export type ThemeColor = {
    50: string;
    100?: string;
    300: string;
    500: string;
    700: string;
    900: string;
    contrastText?: string;
};
export type NeutralColor = Omit<ThemeColor, "contrastText"> & {
    0: string;
    100: string;
    200: string;
    400: string;
    600: string;
    800: string;
};
interface DefaultTheme {
    spacers: any;
    colors: {
        primary: ThemeColor;
        secondary: ThemeColor & {
            A400: string;
        };
        neutral: NeutralColor;
        success: ThemeColor;
        danger: ThemeColor;
        info: ThemeColor;
        warning: ThemeColor;
        blue: ThemeColor;
        green: ThemeColor;
        magenta: ThemeColor;
        yellow: ThemeColor;
        orange: ThemeColor;
        pink: Pick<ThemeColor, 50 | 500 | 900>;
        purple: Pick<ThemeColor, 50 | 500 | 900>;
        navyBlue: Pick<ThemeColor, 500>;
        white: Omit<NeutralColor, 0>;
        mobileApp: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        audit: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        promo: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        campaignCreator: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        keywordPlanner: Pick<ThemeColor, 50 | 500 | 700 | 900> & {
            800: string;
        };
        bannerCreator: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        adsAssistant: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        alt1: Pick<ThemeColor, 50 | 500 | 700 | 900>;
        alt2: Pick<ThemeColor, 50 | 500 | 900>;
        alt3: Pick<ThemeColor, 50 | 500 | 900>;
        googleAds: Pick<ThemeColor, 500>;
        facebookAds: Pick<ThemeColor, 500>;
        instagramAds: Pick<ThemeColor, 500>;
        twitterAds: Pick<ThemeColor, 500>;
        microsoftAds: Pick<ThemeColor, 500>;
        linkedinAds: Pick<ThemeColor, 500>;
        googleMerchant: Pick<ThemeColor, 500>;
        acens: ThemeColor;
        telefonica: ThemeColor;
        hostalia: ThemeColor;
        movistar: ThemeColor;
        managedAds: ThemeColor;
        christmas: ThemeColor;
        spring: Pick<ThemeColor, 50 | 100 | 500 | 900>;
    };
    typography: {
        font1: string;
        font2: string;
        fontWeight: number;
        fontSizeBase: {
            constant: number;
            unit: string;
        };
        lineHeight: number;
        color: string;
        sizing: {
            h1: number;
            h2: number;
            h3: number;
            h4: number;
            h5: number;
            h6: number;
            body0: number;
            body1: number;
            body2: number;
            body3: number;
            span: number;
        };
        variants: {
            title: CSSObject;
            subtitle: CSSObject;
            title2: CSSObject;
            paragraph: CSSObject;
            inputText: CSSObject;
            label: CSSObject;
            small: CSSObject;
            smallItalic: CSSObject;
            caption: CSSObject;
        };
    };
    shadows: {
        none: string;
        hover: string;
        normal: string;
    };
    borderRadius: {
        small: string;
        normal: string;
        full: string;
    };
    formControls: {
        heights: {
            normal: string;
        };
    };
    transitions: {
        easings: {
            agressive: string;
            ease_in_out: string;
        };
        duration: {
            short: string;
            quick: string;
        };
    };
    spaces: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        "3xl": string;
        "4xl": string;
        apply: (key: string) => string;
    };
    breakpoints: {
        values: {
            sm: number;
            md: number;
            lg: number;
        };
        up: (key: string) => string;
        down: (key: string) => string;
    };
}
declare module "@emotion/react" {
    interface Theme extends DefaultTheme {
    }
}
import { Theme as MaterialTheme } from "@material-ui/core/styles/createTheme";
declare module "@material-ui/core/styles/createTheme" {
    interface Theme extends MaterialTheme {
        cleverUI: DefaultTheme;
    }
}
export default DefaultTheme;
