import * as React from 'react';
export type ButtonOwnProps<E extends React.ElementType = React.ElementType> = {
    /**
     * Appearece attribute
     * @default 'primary'
     */
    variant?: "primary" | "secondary";
    /**
     * If `true` the component is disabled and aria-busy=`true`
     */
    isLoading?: boolean;
    /**
     * Allow use another component as handle
     */
    component?: E;
    /**
     * Type attribute applied when the `component` is `button`
     * @default 'button'
     */
    type?: React.ButtonHTMLAttributes<HTMLButtonElement>['type'];
    /**
     * If `true`, the component is disabled
     * @default false
     */
    disabled?: boolean;
    /**
     * Transform Button to anchor Element
     */
    href?: string;
    /**
    * Label to show when isLoading=`true`
    */
    loadingLabel?: string;
    /**
     * If `_blank` add the atribute ref=`noopener`for safety reasons
     */
    target?: React.AnchorHTMLAttributes<HTMLAnchorElement>["target"];
    className?: string;
    sx?: React.CSSProperties & any;
};
export type ButtonProps<E extends React.ElementType> = ButtonOwnProps<E> & Omit<React.ComponentProps<E>, keyof ButtonOwnProps>;
